namespace Eco.Mods.TechTree
{
  using System;
  using System.Collections.Generic;
  using System.ComponentModel;
  using Eco.Gameplay.Blocks;
  using Eco.Gameplay.Components;
  using Eco.Gameplay.Components.Auth;
  using Eco.Gameplay.DynamicValues;
  using Eco.Gameplay.Economy;
  using Eco.Gameplay.Housing;
  using Eco.Gameplay.Interactions;
  using Eco.Gameplay.Items;
  using Eco.Gameplay.Minimap;
  using Eco.Gameplay.Objects;
  using Eco.Gameplay.Players;
  using Eco.Gameplay.Property;
  using Eco.Gameplay.Skills;
  using Eco.Gameplay.Systems.TextLinks;
  using Eco.Gameplay.Pipes.LiquidComponents;
  using Eco.Gameplay.Pipes.Gases;
  using Eco.Gameplay.Systems.Tooltip;
  using Eco.Shared;
  using Eco.Shared.Math;
  using Eco.Shared.Localization;
  using Eco.Shared.Serialization;
  using Eco.Shared.Utils;
  using Eco.Shared.View;
  using Eco.Shared.Items;
  using Eco.Gameplay.Pipes;
  using Eco.World.Blocks;


    //PlantFiberItem added Fuel for Mod
    [Fuel(4000)]
    public partial class PlantFibersItem :  Item {  }

    [Serialized]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    [RequireComponent(typeof(CraftingComponent))]
    [RequireComponent(typeof(FuelSupplyComponent))]
    [RequireComponent(typeof(FuelConsumptionComponent))]
    [RequireComponent(typeof(SolidGroundComponent))]
    public partial class ComposterObject : WorldObject
    {
      public override string FriendlyName {get { return "Composter";}}

      private static Type[] fuelTypeList = new Type[]
      {
        typeof(PlantFibersItem),
      };

      protected override void Initialize()
      {
        this.GetComponent<MinimapComponent>().Initialize("Crafting");
        this.GetComponent<FuelSupplyComponent>().Initialize(2, fuelTypeList);
        this.GetComponent<FuelConsumptionComponent>().Initialize(20);
      }

      public override void Destroy()
      {
        base.Destroy();
      }
    }

    [Serialized]
    public partial class ComposterItem :WorldObjectItem<ComposterObject>
    {
      public override string FriendlyName {get {return "Composter";}}
      public override string Description { get { return "A Tool to compost organic Materials to Dirt.";}}

      static ComposterItem() { }
    }

    public partial class ComposterRecipe : Recipe
    {
      public ComposterRecipe()
      {
        this.Products = new CraftingElement[]
        {
          new CraftingElement<ComposterItem>(),
        };

        this.Ingredients = new CraftingElement[]
        {
          new CraftingElement<BoardItem>(24),
          new CraftingElement<HewnLogItem>(4),
          new CraftingElement<LogItem>(2),
        };
        this.CraftMinutes = new ConstantValue(2);
        this.Initialize("Composter", typeof(ComposterRecipe));
        CraftingComponent.AddRecipe(typeof(WorkbenchObject), this);
      }
    }

    #region ComposterCrafingRecipes
    public partial class DirtFarnRecipe : Recipe
    {
      public DirtFarnRecipe(){
        this.Products = new CraftingElement[]
        {
          new CraftingElement<DirtItem>(),
        };

        this.Ingredients = new CraftingElement[]
        {
          new CraftingElement<FiddleheadsItem>(20),
        };

        this.CraftMinutes = new ConstantValue(1);
        this.Initialize("Dirt", typeof(DirtFarnRecipe));
        CraftingComponent.AddRecipe(typeof(ComposterObject), this);
      }
    }

    public partial class DirtPlantRecipe : Recipe
    {
      public DirtPlantRecipe(){
        this.Products = new CraftingElement[]
        {
          new CraftingElement<DirtItem>(),
        };

        this.Ingredients = new CraftingElement[]
        {
          new CraftingElement<PlantFibersItem>(30),
        };

        this.CraftMinutes = new ConstantValue(1);
        this.Initialize("Dirt", typeof(DirtPlantRecipe));
        CraftingComponent.AddRecipe(typeof(ComposterObject), this);
      }
    }

    public partial class DirtFarnSeedRecipe : Recipe
    {
      public DirtFarnSeedRecipe(){
        this.Products = new CraftingElement[]
        {
          new CraftingElement<DirtItem>(),
        };

        this.Ingredients = new CraftingElement[]
        {
          new CraftingElement<FernSporeItem>(20),
        };

        this.CraftMinutes = new ConstantValue(1);
        this.Initialize("Dirt", typeof(DirtFarnSeedRecipe));
        CraftingComponent.AddRecipe(typeof(ComposterObject), this);
      }
    }
    #endregion
}
